# Robotiq 140mm 2-Finger-Adaptive-Gripper 

This package contains the URDF files describing the 140mm stroke gripper from robotiq, also known as series **C3**.

To test the gripper URDF description type 

```
roslaunch robotiq_2f_140_gripper_visualization test_2f_140_model.launch 
```
## Robot Visual
![140](https://user-images.githubusercontent.com/8356912/49428409-463f8580-f7a6-11e8-8278-5246acdc5c14.png)

## Robot Collision 
![1402](https://user-images.githubusercontent.com/8356912/49428407-463f8580-f7a6-11e8-9c4e-df69e478f107.png)
